==> qtjambi-networkauth-5.15.14-sources.jar: io/qt/network/auth/QOAuthHttpServerReplyHandler.java <==
package io.qt.network.auth;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QOAuthHttpServerReplyHandler</p>
 */
public class QOAuthHttpServerReplyHandler extends io.qt.network.auth.QOAuthOobReplyHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOAuthHttpServerReplyHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthHttpServerReplyHandler() {
        this((io.qt.core.QObject)null);
    }
    
    public QOAuthHttpServerReplyHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.network.QHostAddress, short, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    @SuppressWarnings({"exports"})
    public QOAuthHttpServerReplyHandler(io.qt.network.@NonNull QHostAddress address, short port) {
        this(address, port, (io.qt.core.QObject)null);
    }
    
    @SuppressWarnings({"exports"})
    public QOAuthHttpServerReplyHandler(io.qt.network.@NonNull QHostAddress address, short port, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, address, port, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, io.qt.network.QHostAddress address, short port, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #(short, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthHttpServerReplyHandler(short port) {
        this(port, (io.qt.core.QObject)null);
    }
    
    public QOAuthHttpServerReplyHandler(short port, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, port, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, short port, io.qt.core.QObject parent);
    
    @QtUninvokable
    public final java.lang.@NonNull String callbackPath(){
        return callbackPath_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String callbackPath_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final java.lang.@NonNull String callbackText(){
        return callbackText_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String callbackText_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean isListening(){
        return isListening_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isListening_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #listen(io.qt.network.QHostAddress, short)}
     *  with <code>port = 0</code>.</p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final boolean listen(io.qt.network.@NonNull QHostAddress address) {
        return listen(address, (short)0);
    }
    
    /**
     * <p>Overloaded function for {@link #listen(io.qt.network.QHostAddress, short)}</p>
     * <p>with: </p><ul>
     * <li><code>address = new io.qt.network.QHostAddress(io.qt.network.QHostAddress.SpecialAddress.Any)</code></li>
     * <li><code>port = 0</code></li>
     * </ul>
     */
    @QtUninvokable
    public final boolean listen() {
        return listen(new io.qt.network.QHostAddress(io.qt.network.QHostAddress.SpecialAddress.Any), (short)0);
    }
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final boolean listen(io.qt.network.@NonNull QHostAddress address, short port){
        return listen_native_cref_QHostAddress_quint16(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(address), port);
    }
    
    @QtUninvokable
    private native boolean listen_native_cref_QHostAddress_quint16(long __this__nativeId, long address, short port);
    
    @QtUninvokable
    public final short port(){
        return port_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native short port_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void setCallbackPath(java.lang.@NonNull String path){
        setCallbackPath_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), path);
    }
    
    @QtUninvokable
    private native void setCallbackPath_native_cref_QString(long __this__nativeId, java.lang.String path);
    
    @QtUninvokable
    public final void setCallbackText(java.lang.@NonNull String text){
        setCallbackText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @QtUninvokable
    private native void setCallbackText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    @QtUninvokable
    public java.lang.@NonNull String callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String callback_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QOAuthHttpServerReplyHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QOAuthHttpServerReplyHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QOAuthHttpServerReplyHandler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-networkauth-6.3.4-sources.jar: io/qt/network/auth/QOAuthHttpServerReplyHandler.java <==
package io.qt.network.auth;


/**
 * <p>Java wrapper for Qt class QOAuthHttpServerReplyHandler</p>
 */
public class QOAuthHttpServerReplyHandler extends io.qt.network.auth.QOAuthOobReplyHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOAuthHttpServerReplyHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QOAuthHttpServerReplyHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthHttpServerReplyHandler() {
        this((io.qt.core.QObject)null);
    }
    
    public QOAuthHttpServerReplyHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QOAuthHttpServerReplyHandler(io.qt.network.QHostAddress, short, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    @SuppressWarnings({"exports"})
    public QOAuthHttpServerReplyHandler(io.qt.network.QHostAddress address, short port) {
        this(address, port, (io.qt.core.QObject)null);
    }
    
    @SuppressWarnings({"exports"})
    public QOAuthHttpServerReplyHandler(io.qt.network.QHostAddress address, short port, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, address, port, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, io.qt.network.QHostAddress address, short port, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QOAuthHttpServerReplyHandler(short, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthHttpServerReplyHandler(short port) {
        this(port, (io.qt.core.QObject)null);
    }
    
    public QOAuthHttpServerReplyHandler(short port, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, port, parent);
    }
    
    private native static void initialize_native(QOAuthHttpServerReplyHandler instance, short port, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public final java.lang.String callbackPath(){
        return callbackPath_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String callbackPath_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String callbackText(){
        return callbackText_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String callbackText_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void close_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isListening(){
        return isListening_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isListening_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #listen(io.qt.network.QHostAddress, short)}
     *  with <code>port = 0</code>.</p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final boolean listen(io.qt.network.QHostAddress address) {
        return listen(address, (short)0);
    }
    
    /**
     * <p>Overloaded function for {@link #listen(io.qt.network.QHostAddress, short)}</p>
     * <p>with: </p><ul>
     * <li><code>address = new io.qt.network.QHostAddress(io.qt.network.QHostAddress.SpecialAddress.Any)</code></li>
     * <li><code>port = 0</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final boolean listen() {
        return listen(new io.qt.network.QHostAddress(io.qt.network.QHostAddress.SpecialAddress.Any), (short)0);
    }
    
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final boolean listen(io.qt.network.QHostAddress address, short port){
        return listen_native_cref_QHostAddress_unsigned_short(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(address), port);
    }
    
    @io.qt.QtUninvokable
    private native boolean listen_native_cref_QHostAddress_unsigned_short(long __this__nativeId, long address, short port);
    
    @io.qt.QtUninvokable
    public final short port(){
        return port_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native short port_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setCallbackPath(java.lang.String path){
        setCallbackPath_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), path);
    }
    
    @io.qt.QtUninvokable
    private native void setCallbackPath_native_cref_QString(long __this__nativeId, java.lang.String path);
    
    @io.qt.QtUninvokable
    public final void setCallbackText(java.lang.String text){
        setCallbackText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @io.qt.QtUninvokable
    private native void setCallbackText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    @io.qt.QtUninvokable
    public java.lang.String callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String callback_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QOAuthHttpServerReplyHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QOAuthHttpServerReplyHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QOAuthHttpServerReplyHandler instance, QDeclarativeConstructor constructor);
    
}
